@@ -1,26 +1,17 @@
 # Django settings for blog project.
 import os
-import json
 import sys
 from lisa.server.ConfigManager import ConfigManagerSingleton
+DBNAME = 'lisa'
 
 configuration = ConfigManagerSingleton.get().getConfiguration()
 dir_path = ConfigManagerSingleton.get().getPath()
 
-APP_DIR = os.path.dirname( globals()['__file__'] )
+APP_DIR = os.path.dirname(globals()['__file__'])
 PROJECT_PATH = os.path.abspath(os.path.dirname(__file__) + '/../')
 
 sys.path.append(PROJECT_PATH)
 
-DBNAME = 'lisa'
-
-from mongoengine import connect
-connect(DBNAME, host=configuration['database']['server'], port=configuration['database']['port'])
-
-LOGIN_REDIRECT_URL='/'
-LOGIN_URL='login'
-LOGOUT_URL='logout'
-
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
@@ -47,7 +38,7 @@ TIME_ZONE = 'Europe/Paris'
 # http://www.i18nguy.com/unicode/language-identifiers.html
 LANGUAGE_CODE = 'en-us'
 
-SITE_ID = 1
+#SITE_ID = 1
 
 # If you set this to False, Django will make some optimizations so as not
 # to load the internationalization machinery.
@@ -118,10 +109,6 @@ MIDDLEWARE_CLASSES = (
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
 
-AUTHENTICATION_BACKENDS = (
-    'mongoengine.django.auth.MongoEngineBackend',
-)
-
 ROOT_URLCONF = 'lisa.server.web.weblisa.urls'
 
 # Python dotted path to the WSGI application used by Django's runserver.
@@ -133,30 +120,16 @@ TEMPLATE_DIRS = (
     # Don't forget to use absolute paths, not relative paths.
 )
 
+ANONYMOUS_USER_ID = -1
+
 INTERNAL_IPS = ('127.0.0.1',)
 
-DEBUG_TOOLBAR_PANELS = (
-    'debug_toolbar.panels.version.VersionDebugPanel',
-    'debug_toolbar.panels.timer.TimerDebugPanel',
-    'debug_toolbar.panels.settings_vars.SettingsVarsDebugPanel',
-    'debug_toolbar.panels.headers.HeaderDebugPanel',
-    'debug_toolbar.panels.request_vars.RequestVarsDebugPanel',
-    'debug_toolbar.panels.template.TemplateDebugPanel',
-    'debug_toolbar.panels.sql.SQLDebugPanel',
-    'debug_toolbar.panels.signals.SignalDebugPanel',
-    'debug_toolbar.panels.logger.LoggingPanel',
-)
-
-DEBUG_TOOLBAR_CONFIG = {
-    'INTERCEPT_REDIRECTS': False,
-    'ENABLE_STACKTRACES' : True,
-    }
 INSTALLED_APPS = (
+    'interface',
     'django.contrib.auth',
     'mongoengine.django.mongo_auth',
     'django.contrib.contenttypes',
     'django.contrib.sessions',
-    'django.contrib.sites',
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
@@ -164,34 +137,26 @@ INSTALLED_APPS = (
     'tastypie',
     'tastypie_mongoengine',
     'tastypie_swagger',
-    'interface',
-    'manageplugins',
-    'googlespeech',
+    'manageplugins'
 )
 
-# Sequence for each optional app as a dict containing info about the app.
-OPTIONAL_APPS = (
-    {"import": "debug_toolbar", "apps": ("debug_toolbar",),
-        "middleware": ("debug_toolbar.middleware.DebugToolbarMiddleware",)},
+TASTYPIE_SWAGGER_API_MODULE = 'lisa.server.web.weblisa.urls.v1_api'
+TASTYPIE_ABSTRACT_APIKEY = True
+########## MONGO CONFIG ##########
+AUTHENTICATION_BACKENDS = (
+'mongoengine.django.auth.MongoEngineBackend',
 )
 
-# Set up each optional app if available.
-for app in OPTIONAL_APPS:
-    if app.get("condition", True):
-        try:
-            __import__(app["import"])
-        except ImportError:
-            pass
-        else:
-            INSTALLED_APPS += app.get("apps", ())
-            MIDDLEWARE_CLASSES += app.get("middleware", ())
-
-
+#AUTH_USER_MODEL = 'interface.LisaUser'
 AUTH_USER_MODEL = 'mongo_auth.MongoUser'
-MONGOENGINE_USER_DOCUMENT = 'mongoengine.django.auth.User'
+#MONGOENGINE_USER_DOCUMENT = 'mongoengine.django.auth.User'
+MONGOENGINE_USER_DOCUMENT = 'lisa.server.web.interface.models.LisaUser'
 SESSION_ENGINE = 'mongoengine.django.sessions'
 SESSION_SERIALIZER = 'mongoengine.django.sessions.BSONSerializer'
-TASTYPIE_SWAGGER_API_MODULE = 'lisa.server.web.weblisa.urls.v1_api'
+from mongoengine import connect
+connect(DBNAME, host=configuration['database']['server'], port=configuration['database']['port'])
+#########END MONGO CONFIG#######
+
 
 # A sample logging configuration. The only tangible logging
 # performed by this configuration is to send an email to
